// Copyright 2014 Rui Ueyama. Released under the MIT license.

// C11 7.9 Alternative Spellings

#ifndef __ISO646_H
#define __ISO646_H

#define and &&
#define and_eq &=
#define bitand &
#define bitor |
#define compl ~
#define not !
#define not_eq !=
#define or ||
#define or_eq |=
#define xor ^
#define xor_eq ^=

#endif
